..
  This file is part of the Elk Manual
  Copyright (C) 2013 Fraser Tweedale

  elk is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


***
Elk
***

Elk is an object system for Python inspired by Moose_.  It aspires
to implement the features of Moose in idiomatic Python.

Elk is written in pure Python (2.7) and there are no dependencies
beyond the standard library.

.. _Moose: https://metacpan.org/module/Moose

Contents:

.. toctree::
  :maxdepth: 2

  classes
  attributes
  delegation
  construction
  modifiers
  roles


Copyright and license
=====================

Elk is Copyright (C) 2012, 2013 Fraser Tweedale.

The Elk manual is Copyright (C) 2013 Infinity Interactive, Inc.
and Copyright (C) 2013 Fraser Tweedale.

Elk is `free software`_: you can redistribute it and/or modify
it under the terms of the `GNU General Public License`_ as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

.. _free software: http://www.gnu.org/philosophy/free-sw.html
.. _GNU General Public License: http://www.gnu.org/licenses/gpl.html


Contributing
============

The Elk source code is available from
https://github.com/frasertweedale/elk.  Bug reports, patches,
feature requests, code review and documentation are welcomed.

To contribute patches, please use :command:`git send-email` or generate a
pull request on GitHub.  Write a `well formed commit message`_.  If
your patch is nontrivial, update the copyright notice at the top of
each changed file.

.. _well formed commit message: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
